@@ -11,8 +11,9 @@ use IO::All 'io';
 use Email::MIME 1.940;
 use Email::MIME::CreateHTML;
 use Email::Sender::Simple 'sendmail';
+use MIME::Words 'encode_mimewords';
 
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.12'; # VERSION
 
 sub new {
     my $self = shift;
@@ -58,6 +59,16 @@ sub send {
                 ->format( HTML::TreeBuilder->new->parse( $mail->{html} ) );
         }
 
+        my @keys = keys %$mail;
+        for my $name ( qw( to from subject ) ) {
+            my ($key) = grep { lc($_) eq $name } @keys;
+            $mail->{$key} = encode_mimewords( $mail->{$key} )
+                if ( $key and defined $mail->{$key} and $mail->{$key} =~ /[^[:ascii:]]/ );
+        }
+
+        $mail->{'Content-Transfer-Encoding'} //= 'quoted-printable';
+        $mail->{'Content-Type'}              ||= 'text/plain; charset=us-ascii';
+
         # create a headers hashref (delete things from a data copy that known to not be headers)
         my $headers = [
             map {
@@ -146,7 +157,7 @@ Email::Mailer - Multi-purpose emailer for HTML, auto-text, attachments, and temp
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Email-Mailer.svg)](https://travis-ci.org/gryphonshafer/Email-Mailer)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Email-Mailer/badge.png)](https://coveralls.io/r/gryphonshafer/Email-Mailer)
@@ -468,6 +479,28 @@ that and set your own transport, use the "transport" parameter.
         }),
     );
 
+=head1 AUTOMATIC HEADER-IFICATION
+
+There are some automatic header-ification features to be aware of. Unless you
+specify a value, the C<Content-Type> and C<Content-Transfer-Encoding> are
+set as "text/plain; charset=us-ascii" and "quoted-printable" respectively, as
+if you set the following:
+
+    Email::Mailer->send(
+        to        => $to,
+        from      => $from,
+        subject   => $subject,
+        html      => $html,
+
+        'Content-Type'              => 'text/plain; charset=us-ascii',
+        'Content-Transfer-Encoding' => 'quoted-printable',
+    );
+
+Also, normally your C<to>, C<from>, and C<subject> values are left untouched;
+however, for any of these that contain non-ASCII characters, they will be
+mimewords-encoded via L<MIME::Words>. If you don't like how that works, just
+encode them however you'd like to ASCII.
+
 =head1 SEE ALSO
 
 L<Email::MIME>, L<Email::MIME::CreateHTML>, L<Email::Sender::Simple>,
